pub struct PrismaticConstraint<N: RealField + Copy, Handle: BodyHandle> { /* private fields */ }Expand description
A constraint that remove all be one translational degrees of freedom.
Implementations
Sourceimpl<N: RealField + Copy, Handle: BodyHandle> PrismaticConstraint<N, Handle>
impl<N: RealField + Copy, Handle: BodyHandle> PrismaticConstraint<N, Handle>
Sourcepub fn new(
b1: BodyPartHandle<Handle>,
b2: BodyPartHandle<Handle>,
anchor1: Point<N>,
axis1: Unit<Vector<N>>,
anchor2: Point<N>,
) -> Self
pub fn new( b1: BodyPartHandle<Handle>, b2: BodyPartHandle<Handle>, anchor1: Point<N>, axis1: Unit<Vector<N>>, anchor2: Point<N>, ) -> Self
Create a new prismatic constraint that ensures the relative motion between the two
body parts are restricted to a single translation along the axis1 axis (expressed in
the local coordinates frame of b1).
Sourcepub fn set_break_force(&mut self, break_force: N)
pub fn set_break_force(&mut self, break_force: N)
The maximum force this joint can absorb before breaking.
Sourcepub fn set_break_torque(&mut self, break_torque: N)
pub fn set_break_torque(&mut self, break_torque: N)
The maximum torque this joint can absorb before breaking.
Sourcepub fn min_offset(&self) -> Option<N>
pub fn min_offset(&self) -> Option<N>
The lower limit, if any, of the relative translation (along the joint axis) of the body parts attached to this joint.
Sourcepub fn max_offset(&self) -> Option<N>
pub fn max_offset(&self) -> Option<N>
The upper limit, if any, of the relative translation (along the joint axis) of the body parts attached to this joint.
Sourcepub fn disable_min_offset(&mut self)
pub fn disable_min_offset(&mut self)
Disable the lower limit of the relative translational motion along the joint axis.
Sourcepub fn disable_max_offset(&mut self)
pub fn disable_max_offset(&mut self)
Disable the upper limit of the relative translational motion along the joint axis.
Sourcepub fn enable_min_offset(&mut self, limit: N)
pub fn enable_min_offset(&mut self, limit: N)
Enables the lower limit of the relative translational motion along the joint axis.
Sourcepub fn enable_max_offset(&mut self, limit: N)
pub fn enable_max_offset(&mut self, limit: N)
Disable the lower limit of the relative translational motion along the joint axis.