ColliderDesc

Struct ColliderDesc 

pub struct ColliderDesc<N: RealField + Copy> { /* private fields */ }
A non-deformable collider builder.

See https://www.nphysics.org/rigid_body_simulations_with_contacts/#colliders for details.

Implementations

Source

impl<N: RealField + Copy> ColliderDesc<N>

pub fn new(shape: ShapeHandle<N>) -> Self

Creates a new collider builder with the given shape.

pub fn default_margin() -> N

The default margin surrounding a collider: 0.01

pub fn user_data(self, data: impl UserData) -> Self

Sets a user-data to be attached to the object being built.

pub fn set_user_data(&mut self, data: Option<impl UserData>) -> &mut Self

Sets the user-data to be attached to the object being built.

pub fn get_user_data(&self) -> Option<&(dyn Any + Send + Sync)>

Reference to the user-data to be attached to the object being built.

pub fn rotation(self, axisangle: Vector<N>) -> Self

pub fn set_rotation(&mut self, axisangle: Vector<N>) -> &mut Self

pub fn translation(self, vector: Vector<N>) -> Self

pub fn set_translation(&mut self, vector: Vector<N>) -> &mut Self

pub fn material(self, material: MaterialHandle<N>) -> Self

pub fn set_material(&mut self, material: MaterialHandle<N>) -> &mut Self

pub fn shape(self, shape: ShapeHandle<N>) -> Self

pub fn set_shape(&mut self, shape: ShapeHandle<N>) -> &mut Self

pub fn margin(self, margin: N) -> Self

pub fn set_margin(&mut self, margin: N) -> &mut Self

pub fn density(self, density: N) -> Self

pub fn set_density(&mut self, density: N) -> &mut Self

pub fn collision_groups(self, collision_groups: CollisionGroups) -> Self

pub fn set_collision_groups( &mut self, collision_groups: CollisionGroups, ) -> &mut Self

pub fn linear_prediction(self, linear_prediction: N) -> Self

pub fn set_linear_prediction(&mut self, linear_prediction: N) -> &mut Self

pub fn angular_prediction(self, angular_prediction: N) -> Self

pub fn set_angular_prediction(&mut self, angular_prediction: N) -> &mut Self

pub fn sensor(self, is_sensor: bool) -> Self

pub fn set_is_sensor(&mut self, is_sensor: bool) -> &mut Self

pub fn position(self, position: Isometry<N>) -> Self

pub fn set_position(&mut self, position: Isometry<N>) -> &mut Self

pub fn ccd_enabled(self, ccd_enabled: bool) -> Self

pub fn set_ccd_enabled(&mut self, ccd_enabled: bool) -> &mut Self

pub fn get_rotation(&self) -> Vector<N>

pub fn get_shape(&self) -> &dyn Shape<N>

pub fn get_translation(&self) -> &Vector<N>

pub fn get_material(&self) -> Option<&dyn Material<N>>

pub fn get_margin(&self) -> N

pub fn get_density(&self) -> N

pub fn get_collision_groups(&self) -> CollisionGroups

pub fn get_linear_prediction(&self) -> N

pub fn get_angular_prediction(&self) -> N

pub fn is_sensor(&self) -> bool

pub fn get_ccd_enabled(&self) -> bool

pub fn get_position(&self) -> &Isometry<N>

pub fn build<Handle: BodyHandle>( &self, parent_handle: BodyPartHandle<Handle>, ) -> Collider<N, Handle>

Build a collider and configure it to be attached to the given parent body part.