DefaultColliderSet

Struct DefaultColliderSet 

pub struct DefaultColliderSet<N: RealField + Copy, Handle: BodyHandle = DefaultBodyHandle> { /* private fields */ }
The default set containing all the colliders added to the world.

It is based on an arena using generational indices to avoid the ABA problem.

Implementations

Source

impl<N: RealField + Copy, Handle: BodyHandle> DefaultColliderSet<N, Handle>

pub fn new() -> Self

Creates an empty set.

pub fn insert(&mut self, collider: Collider<N, Handle>) -> DefaultColliderHandle

Adds a collider to this set.

pub fn remove( &mut self, to_remove: DefaultColliderHandle, ) -> Option<Collider<N, Handle>>

Removes a collider from this set.

pub fn get(&self, handle: DefaultColliderHandle) -> Option<&Collider<N, Handle>>

Gets a reference to the collider identified by handle.

pub fn get_mut( &mut self, handle: DefaultColliderHandle, ) -> Option<&mut Collider<N, Handle>>

Gets a mutable reference to the collider identified by handle.

pub fn iter( &self, ) -> impl Iterator<Item = (DefaultColliderHandle, &Collider<N, Handle>)>

Iterates through all the colliders and their handles.

pub fn iter_mut( &mut self, ) -> impl Iterator<Item = (DefaultColliderHandle, &mut Collider<N, Handle>)>

Mutably iterate through all the colliders and their handles.