pub struct PinSlotConstraint<N: RealField + Copy, Handle: BodyHandle> { /* private fields */ }Expand description
A constraint that removes two translational and two rotational degrees of freedoms.
This is different frmo the cylindrical constraint since the remaining rotation and translation are not restricted to be done wrt. the same axis.
Implementations
Sourceimpl<N: RealField + Copy, Handle: BodyHandle> PinSlotConstraint<N, Handle>
impl<N: RealField + Copy, Handle: BodyHandle> PinSlotConstraint<N, Handle>
Sourcepub fn new(
b1: BodyPartHandle<Handle>,
b2: BodyPartHandle<Handle>,
anchor1: Point<N>,
axis_v1: Unit<Vector<N>>,
axis_w1: Unit<Vector<N>>,
anchor2: Point<N>,
axis_w2: Unit<Vector<N>>,
) -> Self
pub fn new( b1: BodyPartHandle<Handle>, b2: BodyPartHandle<Handle>, anchor1: Point<N>, axis_v1: Unit<Vector<N>>, axis_w1: Unit<Vector<N>>, anchor2: Point<N>, axis_w2: Unit<Vector<N>>, ) -> Self
Creates a new pin-slot constraint.
This will ensure the relative linear motions are always along axis_v1 (here expressed
in the local coordinate frame of b1), and that axis_w1 and axis_w2 always coincide.
All axises and anchors are expressed in the local coordinate frame of their respective body
part.
Sourcepub fn set_break_force(&mut self, break_force: N)
pub fn set_break_force(&mut self, break_force: N)
The maximum force this joint can absorb before breaking.
Sourcepub fn set_break_torque(&mut self, break_torque: N)
pub fn set_break_torque(&mut self, break_torque: N)
The maximum torque this joint can absorb before breaking.