pub struct ColliderData<N: RealField + Copy, Handle: BodyHandle> { /* private fields */ }Expand description
Data stored in each collider.
This is needed by nphysics.
Implementations
Sourceimpl<N: RealField + Copy, Handle: BodyHandle> ColliderData<N, Handle>
impl<N: RealField + Copy, Handle: BodyHandle> ColliderData<N, Handle>
Sourcepub fn new(
margin: N,
density: N,
anchor: ColliderAnchor<N, Handle>,
body_status_dependent_ndofs: usize,
material: MaterialHandle<N>,
) -> Self
pub fn new( margin: N, density: N, anchor: ColliderAnchor<N, Handle>, body_status_dependent_ndofs: usize, material: MaterialHandle<N>, ) -> Self
Initializes data for a collider.
Sourcepub fn user_data(&self) -> Option<&(dyn Any + Send + Sync)>
pub fn user_data(&self) -> Option<&(dyn Any + Send + Sync)>
Retrieves a reference to the user-defined user-data attached to this object.
Sourcepub fn user_data_mut(&mut self) -> Option<&mut (dyn Any + Send + Sync)>
pub fn user_data_mut(&mut self) -> Option<&mut (dyn Any + Send + Sync)>
Retrieves a mutable reference to the user-defined user-data attached to this object.
Sourcepub fn set_user_data(
&mut self,
data: Option<Box<dyn Any + Send + Sync>>,
) -> Option<Box<dyn Any + Send + Sync>>
pub fn set_user_data( &mut self, data: Option<Box<dyn Any + Send + Sync>>, ) -> Option<Box<dyn Any + Send + Sync>>
Sets the user-defined data attached to this object.
Sourcepub fn take_user_data(&mut self) -> Option<Box<dyn Any + Send + Sync>>
pub fn take_user_data(&mut self) -> Option<Box<dyn Any + Send + Sync>>
Replace by None the user-defined data attached to this object and returns the old value.
Sourcepub fn anchor(&self) -> &ColliderAnchor<N, Handle>
pub fn anchor(&self) -> &ColliderAnchor<N, Handle>
The anchor attaching this collider with a body part or deformable body.
Sourcepub fn position_wrt_body(&self) -> Isometry<N>
pub fn position_wrt_body(&self) -> Isometry<N>
The position of this collider geometry wrt. the body it is attached to.
Sourcepub fn body_part(&self, subshape_id: usize) -> BodyPartHandle<Handle>
pub fn body_part(&self, subshape_id: usize) -> BodyPartHandle<Handle>
Handle to the body part containing the given subshape of this collider’s shape.
Sourcepub fn material_mut(&mut self) -> &mut dyn Material<N>
pub fn material_mut(&mut self) -> &mut dyn Material<N>
A mutable reference to this collider’s material.
If the material is shared, then an internal clone is performed
before returning the mutable reference (this effectively calls
the Arc::make_mut method to get a copy-on-write behavior).