pub struct DefaultColliderSet<N: RealField + Copy, Handle: BodyHandle = DefaultBodyHandle> { /* private fields */ }Expand description
The default set containing all the colliders added to the world.
It is based on an arena using generational indices to avoid the ABA problem.
Implementations
Sourceimpl<N: RealField + Copy, Handle: BodyHandle> DefaultColliderSet<N, Handle>
impl<N: RealField + Copy, Handle: BodyHandle> DefaultColliderSet<N, Handle>
Sourcepub fn insert(&mut self, collider: Collider<N, Handle>) -> DefaultColliderHandle
pub fn insert(&mut self, collider: Collider<N, Handle>) -> DefaultColliderHandle
Adds a collider to this set.
Sourcepub fn remove(
&mut self,
to_remove: DefaultColliderHandle,
) -> Option<Collider<N, Handle>>
pub fn remove( &mut self, to_remove: DefaultColliderHandle, ) -> Option<Collider<N, Handle>>
Removes a collider from this set.
Sourcepub fn get(&self, handle: DefaultColliderHandle) -> Option<&Collider<N, Handle>>
pub fn get(&self, handle: DefaultColliderHandle) -> Option<&Collider<N, Handle>>
Gets a reference to the collider identified by handle.
Sourcepub fn get_mut(
&mut self,
handle: DefaultColliderHandle,
) -> Option<&mut Collider<N, Handle>>
pub fn get_mut( &mut self, handle: DefaultColliderHandle, ) -> Option<&mut Collider<N, Handle>>
Gets a mutable reference to the collider identified by handle.
Sourcepub fn iter(
&self,
) -> impl Iterator<Item = (DefaultColliderHandle, &Collider<N, Handle>)>
pub fn iter( &self, ) -> impl Iterator<Item = (DefaultColliderHandle, &Collider<N, Handle>)>
Iterates through all the colliders and their handles.
Sourcepub fn iter_mut(
&mut self,
) -> impl Iterator<Item = (DefaultColliderHandle, &mut Collider<N, Handle>)>
pub fn iter_mut( &mut self, ) -> impl Iterator<Item = (DefaultColliderHandle, &mut Collider<N, Handle>)>
Mutably iterate through all the colliders and their handles.